@@ -39,6 +39,7 @@ class Handler(http.server.BaseHTTPRequestHandler):
             '/sleep_long': self.sleep_long,
             '/short_close': self.short_close,
             '/unclean_8bit_header': self.unclean_8bit_header,
+            '/no_colon_header': self.no_colon_header,
         }
         http.server.BaseHTTPRequestHandler.__init__(self, *args, **kwargs)
 
@@ -179,6 +180,13 @@ class Handler(http.server.BaseHTTPRequestHandler):
         self.wfile.write(b'\r\n')
         self.wfile.write(b'hi\n')
 
+    def no_colon_header(self):
+        self.wfile.write(b'HTTP/1.1 200 OK\r\n')
+        self.wfile.write(b'Content-Length: 3\r\n')
+        self.wfile.write(b'Oops\r\n')
+        self.wfile.write(b'\r\n')
+        self.wfile.write(b'hi\n')
+
 
 class ConcurrentHTTPServer(socketserver.ThreadingMixIn,
 http.server.HTTPServer):
